#ifndef __OID_SATA_H__
#define __OID_SATA_H__

/*
 * This array structure defines a representation of the
 *  MIB being implemented.
 *
 * The type of the array is 'struct variableN', where N is
 *  large enough to contain the longest OID sub-component
 *  being loaded.  This will normally be the maximum value
 *  of the fifth field in each line.  In this case, the second
 *  and third entries are both of size 2, so we're using
 *  'struct variable2'
 *
 * The supported values for N are listed in <agent/var_struct.h>
 *  If the value you need is not listed there, simply use the
 *  next largest that is.
 *
 * The format of each line is as follows
 *  (using the first entry as an areca):
 *      1: ARECASTRING:
 *          The magic number defined in the areca header file.
 *          This is passed to the callback routine and is used
 *            to determine which object is being queried.
 *      2: ASN_OCTET_STR:
 *          The type of the object.
 *          Valid types are listed in <snmp_impl.h>
 *      3: RONLY (or RWRITE):
 *          Whether this object can be SET or not.
 *      4: var_areca:
 *          The callback routine, used when the object is queried.
 *          This will usually be the same for all objects in a module
 *            and is typically defined later in this file.
 *      5: 1:
 *          The length of the OID sub-component (the next field)
 *      6: {1}:
 *          The OID sub-components of this entry.
 *          In other words, the bits of the full OID that differ
 *            between the various entries of this array.
 *          This value is appended to the common prefix (defined later)
 *            to obtain the full OID of each entry.
 */
#define	ARECASTRING		    1
#define ARECAINTEGER		21

struct variable1 raidsys_vars[] = 
{
    // system information
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {1}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {2}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {3}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {4}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {5}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {6}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {7}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {8}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {9}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {10}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {11}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {12}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {13}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {14}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {15}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {16}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {17}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {18}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {19}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {20}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {21}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {22}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {23}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {24}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {25}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {26}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {27}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {28}}
};

struct variable3 hwmon_vars[] = 
{
    // hw monitor
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {1}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {2}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {3}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {4}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {5}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {6}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {7}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {8}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {9}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {10}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {11}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 3, {12, 1, 1}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 3, {12, 1, 2}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 3, {13, 1, 1}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 3, {13, 1, 2}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 3, {14, 1, 1}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 3, {14, 1, 2}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {15}}
};

struct variable1 hdd_vars[] = 
{
    // hdd information
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {1}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {2}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {3}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {4}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {5}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {6}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {7}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {8}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {9}}
};


struct variable1 raidset_vars[] = 
{
    // raidset information
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {1}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {2}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {3}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {4}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {5}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {6}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {7}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {8}}
};

struct variable1 volset_vars[] = 
{
    // volumeset information
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {1}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {2}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {3}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {4}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {5}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {6}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {7}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {8}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {9}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {10}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {11}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {12}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {13}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {14}},
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {15}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {16}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {17}}
};

struct variable1 evt_vars[] = 
{
    // event information
    {ARECAINTEGER, ASN_INTEGER, RONLY, var_areca, 1, {1}},
    {ARECASTRING, ASN_OCTET_STR, RONLY, var_areca, 1, {2}}        
};

#endif


